=========
Reference
=========

.. toctree::

   ballots/index
   converters_ballot/index
   eliminations/index
   matrices/index
   priorities/index
   profiles/index
   rules_in_general/index
   rules_in_particular/index
   scales/index
   scorers/index
   utils/index
